pub enum WinDivertRecvError {
InsufficientBuffer,
NoData,
}Expand description
Possible errors for WinDivertRecv()
Variants
InsufficientBuffer
The captured packet is larger than the provided buffer.
NoData
The handle has been shutdown and the packet queue is empty.