WinDivertPacket

Struct WinDivertPacket 

pub struct WinDivertPacket<'a, L: WinDivertLayerTrait> {
    pub address: WinDivertAddress<L>,
    pub data: Cow<'a, [u8]>,
}
Raw captured packet

Fields

address: WinDivertAddress<L>

Address data

data: Cow<'a, [u8]>

Raw captured data

Implementations

Source

impl<'a> WinDivertPacket<'a, NetworkLayer>

pub unsafe fn new(data: Vec<u8>) -> Self

Create a new network packet from a raw buffer

Safety

address is zeroed, user must fill it with correct data before sending.

pub fn recalculate_checksums( &mut self, flags: ChecksumFlags, ) -> Result<(), WinDivertError>

Recalculate the checksums of the packet This is a noop if the packet is not owned.

Source

impl<'a> WinDivertPacket<'a, ForwardLayer>

pub unsafe fn new(data: Vec<u8>) -> Self

Create a new network forward packet from a raw buffer

Safety

address is zeroed, user must fill it with correct data before sending.

pub fn recalculate_checksums( &mut self, flags: ChecksumFlags, ) -> Result<(), WinDivertError>

Recalculate the checksums of the packet This is a noop if the packet is not owned.

Source

impl<'a, L: WinDivertLayerTrait> WinDivertPacket<'a, L>

pub fn into_owned(self) -> WinDivertPacket<'static, L>

Create an owned packet from a borrowed packet